==> mysql-5.6_5.6.16.orig.tar.gz: mysql-5.6.16/storage/ndb/src/ndbjtie/jtie/test/myjapi/myjapi/MyJapiCtypes.java <==
/*
 Copyright 2010 Sun Microsystems, Inc.
 All rights reserved. Use is subject to license terms.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; version 2 of the License.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * MyJapiCtypes.java
 */

package myjapi;

public class MyJapiCtypes {

    // ----------------------------------------------------------------------
    // Platform-Dependent mappings of all primitive result/parameter types
    // ----------------------------------------------------------------------

    static public native boolean f011();

    static public native boolean f11(boolean p0);
    static public native byte f12(byte p0);
    static public native byte f13(byte p0);
    static public native byte f14(byte p0);
    static public native short f15(short p0);
    static public native short f16(short p0);
    static public native int f17(int p0);
    static public native int f18(int p0);
    static public native int f19(int p0);
    static public native int f20(int p0);
    static public native long f21(long p0);
    static public native long f22(long p0);
    static public native float f23(float p0);
    static public native double f24(double p0);
    static public native double f25(double p0);

    static public native boolean f31(boolean p0);
    static public native byte f32(byte p0);
    static public native byte f33(byte p0);
    static public native byte f34(byte p0);
    static public native short f35(short p0);
    static public native short f36(short p0);
    static public native int f37(int p0);
    static public native int f38(int p0);
    static public native int f39(int p0);
    static public native int f40(int p0);
    static public native long f41(long p0);
    static public native long f42(long p0);
    static public native float f43(float p0);
    static public native double f44(double p0);
    static public native double f45(double p0);
}

==> mysql-5.6.49.tar.gz: mysql-5.6.49/storage/ndb/src/ndbjtie/jtie/test/myjapi/myjapi/MyJapiCtypes.java <==
/*
 Copyright 2010 Sun Microsystems, Inc.
 All rights reserved. Use is subject to license terms.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
 as published by the Free Software Foundation.

 This program is also distributed with certain software (including
 but not limited to OpenSSL) that is licensed under separate terms,
 as designated in a particular file or component or in included license
 documentation.  The authors of MySQL hereby grant you an additional
 permission to link the program and your derivative works with the
 separately licensed software that they have included with MySQL.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License, version 2.0, for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/
/*
 * MyJapiCtypes.java
 */

package myjapi;

public class MyJapiCtypes {

    // ----------------------------------------------------------------------
    // Platform-Dependent mappings of all primitive result/parameter types
    // ----------------------------------------------------------------------

    static public native boolean f011();

    static public native boolean f11(boolean p0);
    static public native byte f12(byte p0);
    static public native byte f13(byte p0);
    static public native byte f14(byte p0);
    static public native short f15(short p0);
    static public native short f16(short p0);
    static public native int f17(int p0);
    static public native int f18(int p0);
    static public native int f19(int p0);
    static public native int f20(int p0);
    static public native long f21(long p0);
    static public native long f22(long p0);
    static public native float f23(float p0);
    static public native double f24(double p0);
    static public native double f25(double p0);

    static public native boolean f31(boolean p0);
    static public native byte f32(byte p0);
    static public native byte f33(byte p0);
    static public native byte f34(byte p0);
    static public native short f35(short p0);
    static public native short f36(short p0);
    static public native int f37(int p0);
    static public native int f38(int p0);
    static public native int f39(int p0);
    static public native int f40(int p0);
    static public native long f41(long p0);
    static public native long f42(long p0);
    static public native float f43(float p0);
    static public native double f44(double p0);
    static public native double f45(double p0);
}
